# ThrottledAPI

This repo aims to be an audacious RateLimiter for python ASGI/WSGI APIs.

## RoadMap

- [ ] Implement for FastAPI, because I really like the framework
- [ ] Generalise for others

## Status

In development ...
